<?php

namespace Drupal\prism\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;
use Drupal\Component\Utility\Html;

/**
 * Provides a filter to highlight code with the prism.js library.
 *
 * @Filter(
 *   id = "prism_filter",
 *   title = @Translation("Highlight code using prism.js"),
 *   description = @Translation("Highlights code inside <code>[prism:~][/prism:~]</code> tags, or <code>&lt;pre&gt;&lt;code class='language-*'&gt;</code> tags."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_REVERSIBLE
 * )
 */
class PrismFilter extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    $processed_text = new FilterProcessResult($text);

    $tags = [];

    // Detect prism tags.
    if (preg_match_all('/\[prism:([^\|\\]]+)\|?([^\\]]*)?\]/i', $text, $tag_match)) {
      $tags = $tag_match[1];
    }

    // If we have prism tags we create a wrapper for every language code block
    // and attach the prism library.
    if ($tags) {
      foreach (array_unique($tags) as $tag) {
        // Ahhh.
        if (preg_match_all('#((?<!\[)\[)(prism:' . $tag . ')((\s+[^\]]*)*)(\])(.*?)((?<!\[)\[/\2\s*\]|$)#s', $text, $match)) {
          foreach ($match[6] as $key => $value) {
            $code = '<div class="prism-wrapper" rel="' . $tag . '"><pre><code class="language-' . $tag . '">' . Html::escape($value) . '</code></pre></div>';
            $text = str_replace($match[0][$key], $code, $text);
          }
        }
      }

      $processed_text->setProcessedText($text);
      $processed_text->addAttachments([
        'library' => [
          'prism/drupal.prism',
        ],
      ]);
    }

    return $processed_text;
  }

}
